about summary refs log tree commit diff
path: root/src/tools
diff options
context:
space:
mode:
authorAlex Crichton <alex@alexcrichton.com>2016-10-03 09:49:39 -0700
committerAlex Crichton <alex@alexcrichton.com>2016-10-06 11:07:23 -0700
commit2148bdfcc7ea7b9614d8cbe596cbe7bb75b57cd1 (patch)
tree4a88c4f26d3a898cb9ac26aa6a06fd074253d5a3 /src/tools
parent7a26aeca77bcf334747eddb630e3b9475149b7f5 (diff)
downloadrust-2148bdfcc7ea7b9614d8cbe596cbe7bb75b57cd1.tar.gz
rust-2148bdfcc7ea7b9614d8cbe596cbe7bb75b57cd1.zip
rustc: Rename rustc_macro to proc_macro
This commit blanket renames the `rustc_macro` infrastructure to `proc_macro`,
which reflects the general consensus of #35900. A follow up PR to Cargo will be
required to purge the `rustc-macro` name as well.
Diffstat (limited to 'src/tools')
-rw-r--r--src/tools/cargotest/main.rs2
-rw-r--r--src/tools/tidy/src/cargo.rs8
2 files changed, 6 insertions, 4 deletions
diff --git a/src/tools/cargotest/main.rs b/src/tools/cargotest/main.rs
index 354cce69127..633ff6271b7 100644
--- a/src/tools/cargotest/main.rs
+++ b/src/tools/cargotest/main.rs
@@ -24,7 +24,7 @@ struct Test {
 const TEST_REPOS: &'static [Test] = &[Test {
                                           name: "cargo",
                                           repo: "https://github.com/rust-lang/cargo",
-                                          sha: "d8936af1390ab0844e5e68b459214f2529c9f647",
+                                          sha: "d3bad1ab29efae414e9b4c24534b2d02b3a59782",
                                           lock: None,
                                       },
                                       Test {
diff --git a/src/tools/tidy/src/cargo.rs b/src/tools/tidy/src/cargo.rs
index 4932fd5147a..a7784e65c5b 100644
--- a/src/tools/tidy/src/cargo.rs
+++ b/src/tools/tidy/src/cargo.rs
@@ -88,9 +88,11 @@ fn verify(tomlfile: &Path, libfile: &Path, bad: &mut bool) {
             continue
         }
 
-        // We want the compiler to depend on the proc_macro crate so that it is built and
-        // included in the end, but we don't want to actually use it in the compiler.
-        if toml.contains("name = \"rustc_driver\"") && krate == "proc_macro" {
+        // We want the compiler to depend on the proc_macro_plugin crate so
+        // that it is built and included in the end, but we don't want to
+        // actually use it in the compiler.
+        if toml.contains("name = \"rustc_driver\"") &&
+           krate == "proc_macro_plugin" {
             continue
         }